from django.shortcuts import render, get_object_or_404
from django.http import HttpResponse, Http404
from django.views.decorators.http import require_safe

from pgp import models

class HttpNotImplementedError(HttpResponse):
    status_code = 501

@require_safe
def lookup(request):
    op = request.GET.get('op', "").lower()
    search = request.GET.get('search', "").lower()
    
    if op not in ["get"]:
        return HttpNotImplementedError("Not implemented")

    if search.startswith("0x"):
        search = search[2:]

    keys = models.PublicKey.objects.filter(keyid__endswith=search)
    keys = [key for key in keys
            if request.user.has_perm("pgp.view_publickey", key)]
    if not keys:
        raise Http404()

    response = HttpResponse("\n".join(k.armor for k in keys),
                            content_type="application/pgp-keys")
    response["Access-Control-Allow-Origin"] = "*"
    response["Access-Control-Allow-Methods"] = "GET, OPTIONS, HEAD"
    return response
